@@ -1,9 +1,9 @@
 class Entity:
     def __init__(self, id_or_dict):
         id = id_or_dict
-        if isinstance(id_or_dict, dict):
+        if type(id_or_dict) is dict:
             id = id_or_dict.get('id')
-        if not isinstance(id, str):
+        if type(id) is not str:
             raise ValueError
         self.id = id
 
@@ -18,9 +18,3 @@ class Entity:
                 continue
             str_list.append(f'{item}: {getattr(self, item)}')
         return ', '.join(str_list)
-
-    @classmethod
-    def of_dict(cls, dict):
-        for arg_name, arg_value in enumerate(dict):
-           a = cls
-        return Entity()
\ No newline at end of file
