@@ -4,7 +4,7 @@ from pik_wrapper.entity.entity import Entity
 class Location(Entity):
     def __init__(self, id_or_dict, name: str = None, sort: int = None):
         super().__init__(id_or_dict)
-        if isinstance(id_or_dict, dict):
+        if type(id_or_dict) is dict:
             name = id_or_dict.get('name')
             sort = id_or_dict.get('sort')
         if type(name) is not str:
